@@ -59,6 +59,7 @@ setClass ('BasicRaster',
 		nrows ='integer',
 		crs = 'CRS',
 		layernames = 'vector',
+		z = 'list',
 		zname='character',
 		zvalue='vector',
 		unit = 'vector'
@@ -69,6 +70,7 @@ setClass ('BasicRaster',
 		nrows= as.integer(1),
 		layernames=c(""),
 		unit=c(""),
+		z = list(),
 		zname='',
 		zvalue='',
 		crs = CRS(as.character(NA))
