@@ -30,6 +30,15 @@ function(x, y, by=1, which=2, subsWithNA=TRUE, filename='', ...) {
 			stop('you cannot use subsWithNA=FALSE if length(which) > 1')
 		}
 		
+		if (is.character(by)) {
+			by <- which(by == colnames(y))[1]
+			if (is.na(by)) {stop("'by' is not a valid column name")}
+		}
+		if (is.character(which)) {
+			by <- which(which == colnames(y))[1]
+			if (is.na(which)) {stop("'which' is not valid column name")}
+		}
+		
 		y <- y[ , c(by, which)]
 
 		tt <- table(y[,1])
@@ -61,7 +70,7 @@ function(x, y, by=1, which=2, subsWithNA=TRUE, filename='', ...) {
 			pb <- pbCreate(tr$n, type=.progress(...))
 			r <- writeStart(r, filename=filename, ...)
 			for (i in 1:tr$n) {
-				v <- getValues(x, row=tr$row[i], nrows=tr$size)
+				v <- getValues(x, row=tr$row[i], nrows=tr$nrows[i])
 				r <- writeValues(r, localmerge(v, y, subsWithNA), tr$row[i])
 				pbStep(pb) 
 			}
